ApiKeyResponse

Struct ApiKeyResponse 

pub struct ApiKeyResponse {
    pub api_key: Option<String>,
    pub date_created: String,
    pub date_expires: Option<String>,
    pub date_last_used: Option<String>,
    pub id: String,
    pub name: String,
    pub prefix: String,
    pub suffix: String,
}
ApiKeyResponse : Response containing an API key. This key is used in conjunction with the APIKey model to authenticate users in the API.

Fields

api_key: Option<String>date_created: String

The date that the API key was created.

date_expires: Option<String>date_last_used: Option<String>id: String

The database ID for the API key. Used when deleting keys.

name: String

The human-readable name for the API key used for managing keys.

prefix: String

The non-secret key prefix.

suffix: String

The non-secret key suffix. Helpful for identifying keys if a name wasn’t specified at creation time.

Implementations

Source

impl ApiKeyResponse

pub fn new( api_key: Option<String>, date_created: String, date_expires: Option<String>, date_last_used: Option<String>, id: String, name: String, prefix: String, suffix: String, ) -> ApiKeyResponse

Response containing an API key. This key is used in conjunction with the APIKey model to authenticate users in the API.