pub struct ProjectInfoResponse {
pub date_created: String,
pub is_public: bool,
pub labels: Vec<String>,
pub latest_circuit: Option<Option<Box<ProjectLatestCircuitResponse>>>,
pub name: String,
pub num_proofs: Option<i64>,
pub project_id: String,
pub tags: Vec<String>,
pub team: String,
pub team_avatar_url: String,
pub team_name: String,
pub team_slug: String,
}Expand description
ProjectInfoResponse : Response for getting project info.
Fields
date_created: StringThe UTC datetime the project was created in ISO8601 format.
is_public: boolWhether the project is public.
labels: Vec<String>Labels for the project.
latest_circuit: Option<Option<Box<ProjectLatestCircuitResponse>>>name: StringThe name of the project.
num_proofs: Option<i64>project_id: StringA unique identifier generated for the project. UUID4 format.
Tags for the project.
team: StringThe name of the team that owns this project.
team_avatar_url: StringURL for the avatar image of the team that owns this project.
team_name: StringThe name of the team that owns this project.
team_slug: StringThe slug of the team that owns this project.
Implementations