pub struct ProofCannotBeCreatedResponse {
pub error: String,
pub exception_id: Option<Box<ExceptionId>>,
pub message: Option<String>,
}Expand description
ProofCannotBeCreatedResponse : Action: Attempt to create a proof with invalid input. Error: The proof cannot be created with the given input.
Fields
error: Stringexception_id: Option<Box<ExceptionId>>message: Option<String>Implementations
Sourceimpl ProofCannotBeCreatedResponse
impl ProofCannotBeCreatedResponse
Sourcepub fn new(error: String) -> ProofCannotBeCreatedResponse
pub fn new(error: String) -> ProofCannotBeCreatedResponse
Action: Attempt to create a proof with invalid input. Error: The proof cannot be created with the given input.