pub struct ProofHistogramResponse {
pub bin_size: i64,
pub data: Vec<Value>,
pub end_time: String,
pub start_time: String,
}Expand description
ProofHistogramResponse : Response for producing proof histograms.
Fields
bin_size: i64The bin size in seconds.
data: Vec<Value>A list of dictionaries in the format: { 'bin': '2021-01-01T00:00:00Z', 'ready': 2, 'failed': 1, 'in_progress': 3, 'queued': 4, } where ‘bin’ is an ISO8601 timestamp indicating the start of the bin, and proof status keys (e.g. ‘ready’) indicating the number of proofs with that status in the bin.
end_time: StringThe end of the histogram in timezone-aware ISO8601 format.
start_time: StringThe start of the histogram in timezone-aware ISO8601 format.
Implementations