pub enum ProofInput {
Json(Value),
String(String),
}Expand description
ProofInput : An object mapping proof input variable names to their values. Can be a raw JSON object or a string serialized as JSON or TOML.
Variants
Implementations
Sourceimpl ProofInput
impl ProofInput
Sourcepub fn new() -> ProofInput
pub fn new() -> ProofInput
An object mapping proof input variable names to their values. Can be a raw JSON object or a string serialized as JSON or TOML.