pub struct ProofInfoResponse {Show 32 fields
pub proof_id: String,
pub circuit_name: String,
pub project_name: String,
pub circuit_id: String,
pub circuit_type: CircuitType,
pub date_created: String,
pub meta: HashMap<String, String>,
pub perform_verify: bool,
pub status: JobStatus,
pub finished_processing: bool,
pub verified: Option<bool>,
pub team: String,
pub team_avatar_url: String,
pub team_name: String,
pub team_slug: String,
pub circuit_team: String,
pub circuit_team_avatar_url: String,
pub circuit_team_slug: String,
pub compute_time: Option<Option<String>>,
pub compute_time_sec: Option<Option<f64>>,
pub compute_times: Option<Option<Box<AnyOfLessThanGreaterThan>>>,
pub file_size: Option<Option<i64>>,
pub proof: Option<Option<Value>>,
pub public: Option<Option<Box<AnyOfLessThanGreaterThan>>>,
pub queue_time: Option<Option<String>>,
pub queue_time_sec: Option<Option<f64>>,
pub smart_contract_calldata: Option<Option<String>>,
pub has_smart_contract_calldata: Option<bool>,
pub has_verification_key: Option<bool>,
pub verification_key: Option<Option<Value>>,
pub warnings: Option<Option<Vec<String>>>,
pub error: Option<Option<String>>,
}Expand description
ProofInfoResponse : Response for getting proof info.
Fields
proof_id: StringA unique identifier generated for the proof. UUID4 format.
circuit_name: Stringproject_name: StringThe name of the project associated with this proof.
circuit_id: StringThe circuit_id of the circuit associated with this proof. UUID4 format.
circuit_type: CircuitTypeThe development framework used to write the circuit. This is specified during creation in the included sindri.json file.
date_created: StringThe UTC datetime the circuit was uploaded in ISO8601 format.
meta: HashMap<String, String>Metadata keys and values for the proof that were specified at creation time.
perform_verify: boolA boolean indicating whether an internal verification check occurred during the proof creation.
status: JobStatusThe status of the proof job.
finished_processing: boolThe job is finished processing and waiting/polling can be terminated.
verified: Option<bool>team: StringThe name of the team that owns this proof.
team_avatar_url: StringURL for the avatar image of the team that owns this proof.
team_name: StringThe name of the team that owns this proof.
team_slug: StringThe slug of the team that owns this proof.
circuit_team: StringThe name of the team that owns the circuit associated with this proof.
circuit_team_avatar_url: StringURL for the avatar image of the team that owns the circuit associated with this proof.
circuit_team_slug: StringThe slug of the team that owns the circuit associated with this proof.
compute_time: Option<Option<String>>compute_time_sec: Option<Option<f64>>compute_times: Option<Option<Box<AnyOfLessThanGreaterThan>>>Detailed compute times for the proof generation.
file_size: Option<Option<i64>>proof: Option<Option<Value>>public: Option<Option<Box<AnyOfLessThanGreaterThan>>>The public outputs of the circuit.
queue_time: Option<Option<String>>queue_time_sec: Option<Option<f64>>smart_contract_calldata: Option<Option<String>>has_smart_contract_calldata: Option<bool>Boolean indicating whether this proof has smart contract calldata available.
has_verification_key: Option<bool>Boolean indicating whether this proof’s circuit has a verification key available.
verification_key: Option<Option<Value>>warnings: Option<Option<Vec<String>>>error: Option<Option<String>>Implementations
Sourceimpl ProofInfoResponse
impl ProofInfoResponse
Sourcepub fn new(
proof_id: String,
circuit_name: String,
project_name: String,
circuit_id: String,
circuit_type: CircuitType,
date_created: String,
meta: HashMap<String, String>,
perform_verify: bool,
status: JobStatus,
finished_processing: bool,
verified: Option<bool>,
team: String,
team_avatar_url: String,
team_name: String,
team_slug: String,
circuit_team: String,
circuit_team_avatar_url: String,
circuit_team_slug: String,
) -> ProofInfoResponse
pub fn new( proof_id: String, circuit_name: String, project_name: String, circuit_id: String, circuit_type: CircuitType, date_created: String, meta: HashMap<String, String>, perform_verify: bool, status: JobStatus, finished_processing: bool, verified: Option<bool>, team: String, team_avatar_url: String, team_name: String, team_slug: String, circuit_team: String, circuit_team_avatar_url: String, circuit_team_slug: String, ) -> ProofInfoResponse
Response for getting proof info.